@@ -22,7 +22,7 @@ using namespace std;
 
 class ScoreQZ : public Score{
 public:
-    ScoreQZ(double confidenceTarget, double confidenceMin, double confidenceMax); 
+    ScoreQZ();
     virtual ~ScoreQZ();
     virtual vector <int> getIndices (int N, int p, double * data);
     virtual vector <int> setIndices (int N, int p, double * data, bool index);
